//
// GINZA向け検索3列表示+オートページャー+NG機能
//
if (typeof ap3col === 'undefined') ap3col = {};

ap3col.REVISION = '131221';

ap3col.onReadyFunc = function($) {
	ap3col.addNGID = function(elem) {
		var $item = $(elem).closest('li.item_3col');
		var smid = $item.attr('data-id');
		if (smid) {
			$item.addClass('item_ng');
			set_ng_params('NGvideoId.txt?' + smid);
			fadeout_ng_items(3000);
			show_ng_status(smid);
		}
	};
	ap3col.addNGtitle = function(elem) {
		var $item = $(elem).closest('li.item_3col');
		var title = get_item_title($item);
		if (title) {
			var regex = prompt('NGタイトルに追加する文字列を正規表現で指定', title);
			if (regex) {
				var re = new RegExp(regex);
				$('li.item_3col').each(function() {
					if ((title = get_item_title(elem)) && title.match(re)) {
						$(elem).addClass('item_ng');
					}
				});
				set_ng_params('NGtitle.txt?' + encodeURIComponent(regex));
				fadeout_ng_items(5000);
				show_ng_status(regex);
			}
		}
	};
	$(window).on('beforeunload', function() {
		flush_ng_params();
		window.scrollTo(0, 0); // リロード前にページ先頭へ戻しておく
	});
	if (ap3col.IS_DISABLED || $('.videoList02').size() == 0) {
		return; // 3列表示以外では機能しない
	}
	if (typeof ap3col.LOADING_HEIGHT !== 'number') {
		// キーワード検索はフッターが長いのでタグ検索より大きめの値にする
		ap3col.LOADING_HEIGHT = location.pathname.indexOf('/search/') == 0 ? 1000 : 600;
	}
	setup_pager_event();
	var links = { prev: get_link('prev'), next: get_link('next') };
	var loading = false, errors = 0;
	var timer = setInterval(function() {
		if (!links.next) {
			clearInterval(timer);
		} else if (get_remain_height() < ap3col.LOADING_HEIGHT && !loading) {
			load_items('next');
		}
	}, 500);
	
	function load_items(rel) {
		var url = links[rel];
		var m, page_no = null;
		if (m = url.match(/page=(\d+)/)) {
			page_no = 'page ' + m[1];
			set_status('loading <a href="' + url + '">' + page_no + '</a> ... ');
		}
		loading = true;
		$.ajax({
			type: 'GET', url: url,
			success: function(html) {
				if (!ap3col.NO_REPLACE && history.pushState) {
					var state = { page: page_no, url: url };
					if (history.state == null) { // 最初のページだけ履歴に残す
						history.pushState(state, state.page, url);
					} else {
						history.replaceState(state, state.page, url);
					}
				}
				links[rel] = get_link(rel, html);
				var $page = $(html);
				var $items = $('.item_3col', $page);
				if (rel == 'prev') {
					$('.videoList02 > ul.list > li:first-child').before($items);
					$('div.pager').html($('div.pager', $page).html());
					setup_pager_event();
				} else { // next
					$('.videoList02 > ul.list > li:last-child').after($items);
				}
				add_ng_count(parseInt($('#ap3col_ngcount', $page).text()));
				errors = 0;
				loading = false;
				append_status('done.', 2000);
			},
			error: function(xhr, status) {
				if (errors++ < 5) {
					append_status(status + ', retrying...');
					setTimeout(function(){ loading = false }, 5000);
				} else {
					append_status(status + ', give up!');
					clearInterval(timer);
				}
			}
		});
	}
	function setup_pager_event() {
		$('div.pager > a').click(function(e) {
			if (e.target.href == links.prev) {
				load_items('prev');
				return false; // 挿入するのでページ推移させない
			}
			return true;
		});
	}
	function get_link(rel, html) {
		var link;
		if (typeof html === 'string') {
			var m = html.match(new RegExp('<link\\s+rel="' + rel + '"\\s+href="([^"]+)"'));
			if (m) link = m[1];
		} else {
			link = $('link[rel=' + rel + ']').attr('href');
		}
		return link ? link.replace(/&amp;/g, '&') : undefined;
	}
	function add_click_event(elem, callback, title) {
		if (typeof title === 'string') {
			$(elem).attr('title', title);
		}
		$(elem).css('cursor', 'pointer').click(callback);
	}
	function set_status(content, extra) {
		var $status = $('#ap3col_status');
		if (typeof content === 'string') {
			$status.html(content);
		}
		if (typeof extra === 'function') {
			add_click_event($status, extra);
		} else {
			$status.css('cursor', 'auto').unbind();
		}
		$status.show();
		if (typeof extra === 'number') {
			$status.fadeOut(extra);
		}
	}
	function append_status(content, extra) {
		set_status($('#ap3col_status').html() + content, extra);
	}
	function clear_status() {
		$('#ap3col_status').remove();
	}
	var ng_params = null;
	function set_ng_params(params) {
		flush_ng_params();
		ng_params = params;
	}
	function flush_ng_params() {
		if (ng_params) {
			var ng_url = '/cache/addlist/' + ng_params;
			clear_ng_params();
			$.ajax({
				type: 'GET', url: ng_url, error: function(xhr, status) {
					show_status('flush_ng_params(' + status + '): ' + ng_url);
				}
			});
			
		}
	}
	function clear_ng_params() {
		ng_params = null;
	}
	function add_ng_count(ngcount) {
		if (ngcount > 0) {
			var $ngcount = $('#ap3col_ngcount');
			$ngcount.text(parseInt($ngcount.text()) + ngcount);
			$ngcount.parent().show();
		}
	}
	var fadeout_timer = 0;
	function fadeout_ng_items(speed) {
		$('li.item_ng').fadeOut(speed);
		if (fadeout_timer) {
			clearTimeout(fadeout_timer);
		}
		fadeout_timer = setTimeout(function() {
			fadeout_timer = 0;
			var $items = $('li.item_ng');
			$items.removeClass('item_ng').remove();
			clear_status();
			add_ng_count($items.size());
			flush_ng_params();
		}, speed + 500);
	}
	function show_ng_status(ngword) {
		var m = ngword.match(/[a-z]{2}\d+/);
		set_status('[' + ngword + '] をNG' + (m ? 'ID' : 'タイトル') + 'に追加します' +
				'【クリックでキャンセル】', function() {
			clear_ng_params();
			clear_status();
			$('li.item_ng').removeClass('item_ng').stop().fadeTo('fast', 1).unbind();
		});
	}
	function get_item_title(elem) {
		return $(elem).find('.itemTitle a').attr('title');
	}
	function get_remain_height() {
		var st = document.documentElement.scrollTop    || document.body.scrollTop;
		var sh = document.documentElement.scrollHeight || document.body.scrollHeight;
		var ch = document.documentElement.clientHeight || window.innerHeight;
		return sh - (st + ch);
	}
};

//
// ニコニ広告がブロックされるとエラーが発生して後続の $(document).ready() が機能しないので
//
document.addEventListener('DOMContentLoaded', function() {
	ap3col.onReadyFunc(jQuery);
}, false);